@@ -2,7 +2,7 @@ from django.contrib.auth.decorators import login_required
 from django.db.models.loading import cache
 from django.http import HttpResponse, HttpResponseRedirect, \
     HttpResponseServerError, HttpResponseBadRequest
-from follow.utils import follow as _follow, unfollow as _unfollow
+from follow.utils import follow as _follow, unfollow as _unfollow, toggle as _toggle
 
 def check(func):
     """ 
@@ -44,3 +44,9 @@ def unfollow(request, app, model, id):
     return _unfollow(request.user, obj)
 
 
+@login_required
+@check
+def toggle(request, app, model, id):
+    model = cache.get_model(app, model)
+    obj = model.objects.get(pk=id)
+    return _toggle(request.user, obj)
